==> svm-22.3.0-sources.jar: com/oracle/svm/core/jfr/JfrJavaEvents.java <==
/*
 * Copyright (c) 2019, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jfr;

import java.util.ArrayList;
import java.util.List;
import jdk.jfr.Event;
import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;

/**
 * Holds all JFR Java-level event classes.
 */
public class JfrJavaEvents {
    private static final List<Class<? extends Event>> EVENT_CLASSES = new ArrayList<>();

    @Platforms(Platform.HOSTED_ONLY.class)
    public static void registerEventClass(Class<? extends Event> eventClass) {
        EVENT_CLASSES.add(eventClass);
    }

    public static List<Class<? extends Event>> getAllEventClasses() {
        return EVENT_CLASSES;
    }
}

==> svm-23.0.1-sources.jar: com/oracle/svm/core/jfr/JfrJavaEvents.java <==
/*
 * Copyright (c) 2019, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jfr;

import java.util.ArrayList;
import java.util.List;

import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;

/**
 * Holds all JFR Java-level event classes.
 */
public class JfrJavaEvents {
    private static final List<Class<? extends jdk.internal.event.Event>> EVENT_CLASSES = new ArrayList<>();
    private static final List<Class<? extends jdk.jfr.Event>> JFR_EVENT_CLASSES = new ArrayList<>();

    @Platforms(Platform.HOSTED_ONLY.class)
    @SuppressWarnings("unchecked")
    public static synchronized void registerEventClass(Class<? extends jdk.internal.event.Event> eventClass) {
        EVENT_CLASSES.add(eventClass);
        if (jdk.jfr.Event.class.isAssignableFrom(eventClass)) {
            JFR_EVENT_CLASSES.add((Class<? extends jdk.jfr.Event>) eventClass);
        }
    }

    public static List<Class<? extends jdk.internal.event.Event>> getAllEventClasses() {
        return EVENT_CLASSES;
    }

    public static List<Class<? extends jdk.jfr.Event>> getJfrEventClasses() {
        return JFR_EVENT_CLASSES;
    }
}
